.. octavia-specs documentation master file

====
Main
====

.. toctree::
   :glob:
   :maxdepth: 1

   main/*
   main/*/*

======================
Project Specifications
======================

Version 0.5 specs:

.. toctree::
   :glob:
   :maxdepth: 1

   specs/version0.5/*

Version 1:

.. toctree::
   :glob:
   :maxdepth: 1

   specs/version1/*

====================
Design Documentation
====================

Version 0.5:

.. toctree::
   :glob:
   :maxdepth: 1

   design/version0.5/*

==================
Indices and tables
==================

* :ref:`search`
